@@ -81,9 +81,9 @@
  */
 
 #define VERSION		"2.5"			/* Version number... */
-#define VERS_DATE	"August 31, 1999"		/* for elm -v option */
+#define VERS_DATE	"January 11, 2000"		/* for elm -v option */
 #define WHAT_STRING	\
-	"@(#) Version 2.5, USENET supported version PL2"
+	"@(#) Version 2.5, USENET supported version PL3"
 
 #include <sys/types.h>	/* for fundamental types */
 #include <stdio.h>	/* Must get the _IOEOF flag for feof() on Convex */
@@ -414,7 +414,7 @@ struct header_rec {
 	char subject[STRING];   /** The subject of the mail	**/
 	char mailx_status[WLEN];/** mailx status flags (RO...)	**/
 	char allfrom[STRING];	/** The whole, unparsed From: field **/
-	char allto[LONG_STRING];/** all to/cc fields, not just first **/
+	char allto[VERY_LONG_STRING];/** all to/cc fields, not just first **/
 	long cc_index;		/** index in allto of cc fields **/
 	struct addrs ml_to;	/** mlist parsed 'to' fields    **/
 	long ml_cc_index;	/** index in ml_to of cc fields **/
