@@ -325,7 +325,7 @@ EXTERN char charset[SLEN];		/* 8-bit charset for outbound mssgs */
 EXTERN char display_charset[SLEN];	/* charset display can handle */
 EXTERN char charset_compatlist[SLEN];	/* charsets upward compat to US-ASCII */
 
-EXTERN int escape_char INIT('~');	/* '~' or something else... */
+EXTERN unsigned char escape_char INIT('~');	/* '~' or something else... */
 
 EXTERN char *weedlist[MAX_IN_WEEDLIST];	/* header weeding list */
 EXTERN int weedcount;			/* number of headers to check */
