@@ -770,14 +770,14 @@ int add_new_only;
 
 	    /* copy to:, apparently-to: and cc: fields */
 	    else if (fast_header_cmp(buffer, "To", NULL)) {
-	      strfcat(current_header->allto, buffer+3, LONG_STRING);
+	      strfcat(current_header->allto, buffer+3, VERY_LONG_STRING);
 	      in_to_list = TRUE;
 	      current_header->to[0] = '\0';	/* nothing yet */
 	      figure_out_addressee((char *) buffer +3, user_name,
 				   current_header->to);
 	    }
 	    else if (fast_header_cmp(buffer, "Apparently-To", NULL)) {
-	      strfcat(current_header->allto, buffer+14, LONG_STRING);
+	      strfcat(current_header->allto, buffer+14, VERY_LONG_STRING);
 	    }
 	    else if (fast_header_cmp(buffer, "Cc", NULL)) {
 	      strfcat(tmp_cc_list, buffer+3, LONG_STRING);
@@ -821,7 +821,7 @@ int add_new_only;
 	      in_cc_list = FALSE;
 	      if (*tmp_cc_list != '\0') {
 		current_header->cc_index = strlen(current_header->allto);
-		strfcat(current_header->allto, tmp_cc_list, LONG_STRING);
+		strfcat(current_header->allto, tmp_cc_list, VERY_LONG_STRING);
 	      } else
 	        current_header->cc_index = -1;
 	      content_remaining = current_header->content_length;
@@ -835,7 +835,7 @@ int add_new_only;
 	        in_cc_list = FALSE;
 		if (*tmp_cc_list != '\0') {
 		  current_header->cc_index = strlen(current_header->allto);
-		  strfcat(current_header->allto, tmp_cc_list, LONG_STRING);
+		  strfcat(current_header->allto, tmp_cc_list, VERY_LONG_STRING);
 		} else
 		  current_header->cc_index = -1;
 	        content_remaining = current_header->content_length;
@@ -849,7 +849,7 @@ int add_new_only;
 	     */
 	    if (in_to_list == TRUE && !fast_header_cmp(buffer, "To", NULL)) {
 	      if (whitespace(buffer[0])) {
-		strfcat(current_header->allto, buffer, LONG_STRING);
+		strfcat(current_header->allto, buffer, VERY_LONG_STRING);
 	        figure_out_addressee(buffer, user_name, current_header->to);
 	      }
 	      else in_to_list = FALSE;
