@@ -62,6 +62,7 @@ int mssgtype;
     SEND_HEADER *shdr;		/* headers for this message		*/
     SEND_BODYPART *mssg_parts;	/* contents of this message		*/
     SEND_MULTIPART *attachments;/* add'l user-specified attachments	*/
+    SEND_MULTIPART *mp;         /* used to loop thru user attachments   */
     char fname_mssgbody[SLEN];	/* message composition file		*/
     char *fname_fullmssg; 	/* complete message to transmit		*/
     char fname_savecopy[SLEN];	/* selected save copy folder		*/
@@ -337,7 +338,7 @@ message_is_prepared:
 
     /* dup any user-specified attachments onto the message attachments */
     if (attachments != NULL) {
-	SEND_MULTIPART *mp = NULL;
+	mp = NULL;
 	while ((mp = multipart_next(attachments, mp)) != NULL) {
 	    multipart_insertpart(mssg_parts->subparts,
 			MULTIPART_TAIL(mssg_parts->subparts), 
@@ -419,6 +420,26 @@ message_is_prepared:
     }
 
     /* grab a copy if the user so desires... */
+/*  #ifdef SAVE_ATTACHMENT_NAMES this if we decide to make this optional */
+    /* append attachment names to message body to remind user what they did */
+        if (attachments != NULL) {
+      if ((fp_mssgbody = file_open(fname_mssgbody, "a")) == NULL)
+          goto done;
+
+      fprintf(fp_mssgbody, "\n");  /* Blank line to separate */
+
+      mp = NULL;
+      while ((mp = multipart_next(attachments, mp)) != NULL) {
+          fprintf(fp_mssgbody, "(%s)\n",
+                  mp->part->content_header[BP_CONT_DISPOSITION]);
+      }
+
+      if (file_close(fp_mssgbody, fname_mssgbody) < 0)
+          goto done;
+      fp_mssgbody = NULL;
+    }
+/* #endif */
+
     if (fname_savecopy[0] != '\0'
 		&& !save_copy(fname_savecopy, fname_mssgbody, shdr, form)
 		&& sleepmsg > 0) {
